@@ -34,6 +34,10 @@ class Logger:
                 except:
                     pass
 
+            if not 'SOURCE_FOLDER' in os.environ:
+                source = source.replace('venv\\lib\\site-packages\\','')
+                source = source.replace('Windows\\system32\\','')
+
             if not user is None:
                 os.environ['AWS_PROFILENAME'] = user
             else:
