@@ -31,6 +31,12 @@ class SharedData:
         elif mode == 'rw':
             self.s3read = True
             self.s3write = True
+
+        if (Logger.user!='master') & (user=='master'):
+            self.s3write=False
+            mode = 'r'
+        
+        self.mode = mode
                 
         # last download sync datetime
         self.lastsync = pd.DataFrame([])
@@ -66,7 +72,9 @@ class SharedData:
 
     def getMetadata(self, collection):
         if not collection in self.metadata.keys():              
-            self.metadata[collection] = Metadata(collection)
+            self.metadata[collection] = Metadata(collection,\
+                mode=self.mode,sync_frequency_days=self.sync_frequency_days,\
+                user=self.user)
         return self.metadata[collection]
 
     def getSymbols(self, collection):        
