@@ -19,8 +19,8 @@ class SharedDataFeeder():
             else:
                 self.dataset = pd.DataFrame([]) 
         else:
-            Logger.log.error('feeder not found in dataset!')
-            raise Exception('feeder not found in dataset!')    
+            Logger.log.warning('feeder %s not found in dataset!' % (self.feeder))
+            #raise Exception('feeder not found in dataset!')
 
         # DATA DICTIONARY
         # data[period][tag]
