@@ -54,9 +54,17 @@ class SharedDataPeriod:
     def __getitem__(self, tag):
         if not tag in self.tags.keys():
             if isinstance(tag, pd.Timestamp):
-                self.tags[tag] = SharedDataFrame(self, tag)
+                df = SharedDataFrame(self, tag)
+                if not df.data.empty:
+                    self.tags[tag] = df
+                else:
+                    return pd.DataFrame([])
             else:
-                self.tags[tag] = SharedDataTimeSeries(self, tag)        
+                ts = SharedDataTimeSeries(self, tag)
+                if not ts.data.empty:
+                    self.tags[tag] = ts
+                else:
+                    return pd.DataFrame([])
         return self.tags[tag].data
 
     def getTimeIndex(self, startDate):
