@@ -43,13 +43,16 @@ try:
     lastdate = today
     while True:
         today = pd.Timestamp(pd.Timestamp.now().date())
-        wd = shdata['RT/Watchdog']['D1']        
-        if today!=lastdate:            
-            wd[today] = wd[lastdate].copy()
-            # wd.tags[today].Write()
-            lastdate=today
-
+        wd = shdata['WATCHDOG']['D1']
         dfwatchdog = wd[today]
+        if dfwatchdog.empty:
+            df = pd.DataFrame(
+                time.time(),
+                index = [shdata.database],
+                columns = ['watchdog']
+            )
+            wd[today] = df        
+        
         dfwatchdog.loc[DATABASE,'watchdog'] = time.time()
 
         consumer.consume()
